aboutsummaryrefslogtreecommitdiff
path: root/src/google
diff options
context:
space:
mode:
Diffstat (limited to 'src/google')
-rw-r--r--src/google/crash_report.h89
-rw-r--r--src/google/minidump_processor.h (renamed from src/google/crash_report_processor.h)24
-rw-r--r--src/google/symbol_supplier.h5
3 files changed, 15 insertions, 103 deletions
diff --git a/src/google/crash_report.h b/src/google/crash_report.h
deleted file mode 100644
index 22937538..00000000
--- a/src/google/crash_report.h
+++ /dev/null
@@ -1,89 +0,0 @@
-// Copyright (C) 2006 Google Inc.
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-// http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-// CrashReport encapsulates all of the information for a single report,
-// including data sent with the report and data derived by the minidump
-// processor (stack trace, etc.).
-
-#ifndef GOOGLE_CRASH_REPORT_H__
-#define GOOGLE_CRASH_REPORT_H__
-
-#include <vector>
-#include <string>
-#include "google/airbag_types.h"
-#include "google/stack_frame.h"
-
-namespace google_airbag {
-
-using std::vector;
-using std::string;
-
-struct CrashReport {
- // An optional id for the report. This is supplied by the caller
- // and is not used by airbag.
- string report_id;
-
- // An optional id which identifies the client that generated the report.
- string client_id;
-
- // The time that the report was uploaded (milliseconds since the epoch)
- airbag_time_t report_time;
-
- // The uptime of the process before it crashed
- airbag_time_t process_uptime;
-
- // The cumulative uptime of the application for this user
- airbag_time_t cumulative_product_uptime;
-
- // The user's email address, if they provided it
- string user_email;
-
- // Extra comments the user provided, e.g. steps to reproduce the crash
- string user_comments;
-
- // The product which sent this report
- struct Product {
- string name;
- string version;
- };
- Product product;
-
- // The user's operating system
- struct OS {
- string name;
- string version;
- };
- OS os;
-
- // The user's CPU architecture (x86, PowerPC, x86_64, ...)
- string cpu_arch;
-
- // Extra product-specific key/value pairs
- struct ProductData {
- string key;
- string value;
- };
- vector<ProductData> product_data;
-
- // The stack frames for the crashed thread, top-first.m
- // TODO(bryner): accommodate multiple threads
- StackFrames stack_frames;
-
- // The stack trace "signature", which can be used for matching up reports
- string stack_signature;
-};
-
-} // namespace google_airbag
-
-#endif // GOOGLE_CRASH_REPORT_H__
diff --git a/src/google/symbol_supplier.h b/src/google/symbol_supplier.h
index 279e99f2..f0a6e39c 100644
--- a/src/google/symbol_supplier.h
+++ b/src/google/symbol_supplier.h
@@ -24,16 +24,15 @@ namespace google_airbag {
using std::string;
class MinidumpModule;
-struct CrashReport;
class SymbolSupplier {
public:
virtual ~SymbolSupplier() {}
// Returns the path to the symbol file for the given module.
- // report will be the pointer supplied to ProcessReport().
+ // supplier_data is passed through from MinidumpProcessor::Process().
virtual string GetSymbolFile(MinidumpModule *module,
- const CrashReport *report) = 0;
+ void *supplier_data) = 0;
};
} // namespace google_airbag
diff --git a/src/google/crash_report_processor.h b/src/google/minidump_processor.h
index 161bc8cc..9c80ee4e 100644
--- a/src/google/crash_report_processor.h
+++ b/src/google/minidump_processor.h
@@ -12,28 +12,30 @@
// See the License for the specific language governing permissions and
// limitations under the License.
-#ifndef GOOGLE_CRASH_REPORT_PROCESSOR_H__
-#define GOOGLE_CRASH_REPORT_PROCESSOR_H__
+#ifndef GOOGLE_MINIDUMP_PROCESSOR_H__
+#define GOOGLE_MINIDUMP_PROCESSOR_H__
#include <string>
+#include "google/stack_frame.h"
namespace google_airbag {
using std::string;
-struct CrashReport;
class SymbolSupplier;
-class CrashReportProcessor {
+class MinidumpProcessor {
public:
// Initializes this CrashReportProcessor. supplier should be an
// implementation of the SymbolSupplier abstract base class.
- CrashReportProcessor(SymbolSupplier *supplier);
- ~CrashReportProcessor();
+ MinidumpProcessor(SymbolSupplier *supplier);
+ ~MinidumpProcessor();
- // Fills in the stack and other derived data for the CrashReport,
- // using the supplied minidump file. Returns true on success.
- bool ProcessReport(CrashReport *report, const string &minidump_file);
+ // Fills in the given StackFrames vector by processing the minidump file.
+ // supplier_data is an opaque pointer which is passed to
+ // SymbolSupplier::GetSymbolFile(). Returns true on success.
+ bool Process(const string &minidump_file, void *supplier_data,
+ StackFrames *stack_frames);
private:
SymbolSupplier *supplier_;
@@ -41,4 +43,4 @@ class CrashReportProcessor {
} // namespace google_airbag
-#endif // GOOGLE_CRASH_REPORT_PROCESSOR_H__
+#endif // GOOGLE_MINIDUMP_PROCESSOR_H__
@@ -12,28 +12,30 @@
public:
- // Initializes this CrashReportProcessor. supplier should be an
+ // Initializes this MinidumpProcessor. supplier should be an
// implementation of the SymbolSupplier abstract base class.